@@ -1,15 +1,13 @@
 context("Arguments validation")
 
-test_that("the 'data' argument is validated correctly", {
-      data(bison)
-      
+test_that("the 'data' argument is validated correctly", {      
       # the data argument can be a matrix
 #      bison.m <- as.matrix(bison)
 #      Tsout <- Ts.estim(formula = Y ~ biomass + I(biomass^2) + strata(Strata) + cluster(Cluster), data = bison.m)
 #      expect_that(round(Tsout$beta,2), equals(c("biomass"=8.59, "I(biomass^2)"=-7.79)))
 #      ddout <- ddim(formula = Y ~ strata(Strata) + cluster(Cluster), data = bison.m)
 #      expect_that(length(ddout$Sc), equals(20))
-# problme avec testthat que je ne comprends pas...
+# probl?me avec testthat que je ne comprends pas...
       
       # the data argument cannot be missing
       expect_that(Ts.estim(formula = Y ~ biomass + strata(Strata) + cluster(Cluster)),
@@ -25,9 +23,7 @@ test_that("the 'data' argument is validated correctly", {
     })
 
 
-test_that("the 'formula' argument is validated correctly by Ts.estim", {
-      data(bison)
-      
+test_that("the 'formula' argument is validated correctly by Ts.estim", {      
       # the formula argument cannot be missing
       expect_that(Ts.estim(data=bison),
           throws_error("a 'formula' argument is required"))
@@ -42,9 +38,9 @@ test_that("the 'formula' argument is validated correctly by Ts.estim", {
           throws_error("the formula must include a strata term"))
       # no covariates given
       expect_that(Ts.estim(formula = Y ~ strata(Strata) + cluster(Cluster), data = bison),
-          throws_error("at least one covariate must be include in the model"))
+          throws_error("at least one covariate must be included in the model"))
       expect_that(Ts.estim(formula = Y ~ 1 + strata(Strata) + cluster(Cluster), data = bison),
-          throws_error("at least one covariate must be include in the model"))
+          throws_error("at least one covariate must be included in the model"))
       # no response variable given
       expect_that(Ts.estim(formula = ~ biomass + strata(Strata) + cluster(Cluster), data = bison),
           throws_error("a response variable must be given"))
@@ -56,18 +52,16 @@ test_that("the 'formula' argument is validated correctly by Ts.estim", {
           throws_error("variable names figuring in 'formula' should be found among column names of 'data'"))
       # more than one variable given for cluster identification
       expect_that(Ts.estim(formula = Y ~ biomass + strata(Strata) + cluster(Cluster + meadow), data = bison),
-          throws_error("in 'formula', the cluster must be a single variable"))
+          throws_error("in 'formula', the cluster identifier must be a single variable"))
       expect_that(Ts.estim(formula = Y ~ biomass + strata(Strata) + cluster(bison[,c("Cluster","meadow")]), data = bison),
-          throws_error("in 'formula', the cluster must be a single variable"))
+          throws_error("in 'formula', the cluster identifier must be a single variable"))
       
       Ts.estim(formula = Y ~ biomass + strata(Strata + meadow) + cluster(Cluster), data = bison)
       test <- ddim(formula = Y ~ strata(Strata + meadow) + cluster(Cluster), data = bison)
       })
 
 
-test_that("the 'formula' argument is validated correctly by ddim", {
-      data(bison)
-      
+test_that("the 'formula' argument is validated correctly by ddim", {      
       # ddim works even when a covariate is given
       ddout1 <- ddim(formula = Y ~ biomass + strata(Strata) + cluster(Cluster), data = bison)
       expect_that(ncol(ddout1$Ystat), equals(4))
@@ -101,18 +95,16 @@ test_that("the 'formula' argument is validated correctly by ddim", {
           throws_error("variable names figuring in 'formula' should be found among column names of 'data'"))
       # more than one variable given for cluster identification
       expect_that(ddim(formula = Y ~ strata(Strata) + cluster(Cluster + meadow), data = bison),
-          throws_error("in 'formula', the cluster must be a single variable"))
+          throws_error("in 'formula', the cluster identifier must be a single variable"))
       expect_that(ddim(formula = Y ~ strata(Strata) + cluster(bison[,c("Cluster","meadow")]), data = bison),
-          throws_error("in 'formula', the cluster must be a single variable"))
+          throws_error("in 'formula', the cluster identifier must be a single variable"))
       # more than one variable given for strata identification
       expect_that(ddim(formula = Y ~ strata(bison[,c("Strata","meadow")]) + cluster(Cluster), data = bison),
-          throws_error("in 'formula', the strata must be a single variable"))
+          throws_error("in 'formula', the stratum identifier must be a single variable"))
 })
     
 
-test_that("the 'random' argument is validated correctly", {
-      data(bison)
-      
+test_that("the 'random' argument is validated correctly", {      
       # the random argument must be a formula
       expect_that(Ts.estim(formula = Y ~ biomass + strata(Strata) + cluster(Cluster), data = bison, random = "test"),
           throws_error("the 'random' argument must be a formula"))
@@ -127,9 +119,7 @@ test_that("the 'random' argument is validated correctly", {
     })
 
 
-test_that("the Ts.estim function works correctly", {
-      data(bison)
-      
+test_that("the Ts.estim function works correctly", {    
       # only one covariate
       one <- Ts.estim(formula = Y ~ biomass + strata(Strata) + cluster(Cluster), data = bison)
       expect_that(dim(one$D), equals(c(1,1)))
@@ -139,9 +129,9 @@ test_that("the Ts.estim function works correctly", {
 #      colnames(bison.nn) <- NULL
 #      nn <- Ts.estim(formula = bison.nn[,3] ~ bison.nn[,8] + strata(bison.nn[,2]) + cluster(bison.nn[,1]), data = bison.nn,
 #                     random = ~ bison.nn[,8])
-#      # des warnings sont gnrs, mais la rponse est bonne.
+#      # des warnings sont g?n?r?s, mais la r?ponse est bonne.
 #      expect_that(nn$D, is_equivalent_to(one$D))
-# problme avec testthat que je ne comprends pas...
+# probl?me avec testthat que je ne comprends pas...
       
       # Different ways of submitting a model with one covariate give the same result
 #      logic8 <- c(rep(FALSE,7), TRUE, FALSE)
@@ -151,24 +141,24 @@ test_that("the Ts.estim function works correctly", {
       way2 <- Ts.estim(formula = Y ~ biomass + strata(Strata) + cluster(Cluster), data = bison, random = ~ bison[,"biomass"])
       way3 <- Ts.estim(formula = Y ~ biomass + strata(Strata) + cluster(Cluster), data = bison, random = ~ bison[,8])
 #      way4 <- Ts.estim(formula = Y ~ biomass + strata(Strata) + cluster(Cluster), data = bison, random = ~ bison[,logic8])
-# problme avec testthat que je ne comprends pas...
+# probl?me avec testthat que je ne comprends pas...
       way5 <- Ts.estim(formula = Y ~ bison$biomass + strata(Strata) + cluster(Cluster), data = bison, random = ~ biomass)
       way6 <- Ts.estim(formula = Y ~ bison[,"biomass"] + strata(Strata) + cluster(Cluster), data = bison, random = ~ biomass)
       way7 <- Ts.estim(formula = Y ~ bison[,8] + strata(Strata) + cluster(Cluster), data = bison, random = ~ biomass)
 #      way8 <- Ts.estim(formula = Y ~ bison[,logic8] + strata(Strata) + cluster(Cluster), data = bison, random = ~ biomass)
-# ne fonctionne pas, mais fonctionne si c(rep(FALSE,7), TRUE, FALSE) est donn directement plutt que de passer par logic8
+# ne fonctionne pas, mais fonctionne si c(rep(FALSE,7), TRUE, FALSE) est donn? directement plut?t que de passer par logic8
       way9 <- Ts.estim(formula = Y ~ biomass + strata(bison$Strata) + cluster(Cluster), data = bison, random = ~ biomass)
       way10 <- Ts.estim(formula = Y ~ biomass + strata(bison[,"Strata"]) + cluster(Cluster), data = bison, random = ~ biomass)
       way11 <- Ts.estim(formula = Y ~ biomass + strata(bison[,2]) + cluster(Cluster), data = bison, random = ~ biomass)
 #      way12 <- Ts.estim(formula = Y ~ biomass + strata(bison[,logic2]) + cluster(Cluster), data = bison, random = ~ biomass)
-# ne fonctionne pas, mais ce n'est pas grave car il y a plein d'autres faon de spcifier les variables
-# et une erreur relativement informative est gnre
+# ne fonctionne pas, mais ce n'est pas grave car il y a plein d'autres fa?on de sp?cifier les variables
+# et une erreur relativement informative est g?n?r?e
       way13 <- Ts.estim(formula = Y ~ biomass + strata(Strata) + cluster(bison$Cluster), data = bison, random = ~ biomass)
       way14 <- Ts.estim(formula = Y ~ biomass + strata(Strata) + cluster(bison[,"Cluster"]), data = bison, random = ~ biomass)
       way15 <- Ts.estim(formula = Y ~ biomass + strata(Strata) + cluster(bison[,1]), data = bison, random = ~ biomass)
 #      way16 <- Ts.estim(formula = Y ~ biomass + strata(Strata) + cluster(bison[,logic1]), data = bison, random = ~ biomass)
-# ne fonctionne pas, mais ce n'est pas grave car il y a plein d'autres faon de spcifier les variables
-# et une erreur relativement informative est gnre
+# ne fonctionne pas, mais ce n'est pas grave car il y a plein d'autres fa?on de sp?cifier les variables
+# et une erreur relativement informative est g?n?r?e
       way17 <- Ts.estim(formula = bison$Y ~ biomass + strata(Strata) + cluster(Cluster), data = bison, random = ~ biomass)
       way18 <- Ts.estim(formula = bison[,"Y"] ~ biomass + strata(Strata) + cluster(Cluster), data = bison, random = ~ biomass)
       way19 <- Ts.estim(formula = bison[,3] ~ biomass + strata(Strata) + cluster(Cluster), data = bison, random = ~ biomass)
@@ -195,7 +185,7 @@ test_that("the Ts.estim function works correctly", {
 #      way <- Ts.estim(formula = Y ~ mat + strata(Strata) + cluster(Cluster), data = bison)
 #      indic <- c(6,8,9)
 #      way <- Ts.estim(formula = Y ~ as.matrix(bison[,indic]) + strata(Strata) + cluster(Cluster), data = bison)
-# ces faons d'entrer les arguments ne fonctionnent pas : ok car une erreur relativement informative est gnre
+# ces fa?ons d'entrer les arguments ne fonctionnent pas : ok car une erreur relativement informative est g?n?r?e
 
       way1 <- Ts.estim(formula = Y ~ forest + biomass + pmeadow + strata(Strata) + cluster(Cluster), data = bison,
           random = ~ forest + biomass + pmeadow)
@@ -257,6 +247,14 @@ test_that("the Ts.estim function works correctly", {
           data = bison, random = ~ biomass + I(biomass^2), D="UN")
       expect_that(UN1d$D, equals(UN1$D))      
       expect_that(UN1$D[2,1]==0, is_true())      
-      expect_that(UN$D[2,1]!=0, is_true())      
-            
+      expect_that(UN$D[2,1]!=0, is_true())
+      
+      # categorical covariates
+      bison_c <- cbind(bison, catego=ifelse(bison$biomass>0&bison$biomass<0.5,"medium",ifelse(bison$biomass>=0.5,"high","zero")))      
+      Fit_c <- Ts.estim(formula = Y ~ catego + strata(Strata) + cluster(Cluster), data = bison_c, all.m.1=FALSE)
+      expect_that(length(Fit_c$beta), equals(2))
+      
       })
+
+
+
